# Initial Meeting Script

## Initial Script Prepared
- How did you get the idea for the project?  
- Can you elaborate on the project task and what’s needed?  
- What are the things you would like to see in the MVP?  
- Is CodeRabbit a similar solution?  

### Improvements Using *Mom Test* Rules
- Make the conversation casual and let the customer explain their ideas comfortably.  
- Ask questions for deeper understanding of what’s needed, for example:
  - What tool/product is currently being used?  
  - What’s missing with the current tools?  
  - What are some usage scenarios for the project?  

## Additional Questions Asked in the Meeting
- How should the project be (a tool, a webpage, etc.)? Basically, how would you prefer to use the project?  
- Regarding statistics, there is a feature on GitHub where it shows collaborators’ contributions, why don’t we use it?  
- Should we do the project as a CLI?  
